unit adxOLTempCmdBar_IMPL;

interface

uses
  SysUtils, ComObj, ComServ, ActiveX, Variants, adxAddIn, adxOLTempCmdBar_TLB,
  Classes, StdVcl, Outlook2000;

type
  TADX_OL_TempCmdBar = class(TadxAddin, IADX_OL_TempCmdBar)
  end;

  TAddInModule = class(TadxCOMAddInModule)
    ExplorerCmdBar: TadxOlExplorerCommandbar;
    procedure adxCOMAddInModuleAddInInitialize(Sender: TObject);
    procedure adxCOMAddInModuleAddInFinalize(Sender: TObject);
  private
    FExplorers: TExplorers;
    FExplorersList: TList;
  protected
    procedure LoadParams(const CmdBar: TadxOLExplorerCommandBar);
    procedure SaveParams(const CmdBar: TadxOLExplorerCommandBar);
    procedure DoNewExplorer(ASender: TObject; const Explorer: _Explorer);
    procedure DoExplorerClose(ASender: TObject);
  public
  end;

implementation

{$R *.dfm}

{**************************************************}

procedure TAddInModule.LoadParams(const CmdBar: TadxOLExplorerCommandBar);
begin
  with Self.Registry do begin
    if ValueExists(CmdBar.CommandBarName + '_Position') then
      CmdBar.Position := TadxMsoBarPosition(ReadInteger(CmdBar.CommandBarName + '_Position'));
    if ValueExists(CmdBar.CommandBarName + '_Left') then
      CmdBar.CommandBarLeft := ReadInteger(CmdBar.CommandBarName + '_Left');
    if ValueExists(CmdBar.CommandBarName + '_Top') then
      CmdBar.CommandBarTop := ReadInteger(CmdBar.CommandBarName + '_Top');
    if ValueExists(CmdBar.CommandBarName + '_RowIndex') then
      CmdBar.RowIndex := ReadInteger(CmdBar.CommandBarName + '_RowIndex');
  end;
end;

procedure TAddInModule.SaveParams(const CmdBar: TadxOLExplorerCommandBar);
begin
  with Self.Registry do begin
    WriteInteger(CmdBar.CommandBarName + '_Position', Integer(CmdBar.Position));
    WriteInteger(CmdBar.CommandBarName + '_Left', CmdBar.CommandBarLeft);
    WriteInteger(CmdBar.CommandBarName + '_Top', CmdBar.CommandBarTop);
    WriteInteger(CmdBar.CommandBarName + '_RowIndex', CmdBar.RowIndex);
  end;
end;

{**************************************************}

procedure TAddInModule.adxCOMAddInModuleAddInInitialize(Sender: TObject);
begin
  LoadParams(ExplorerCmdBar);
  FExplorersList := TList.Create;
  if OutlookApp.ActiveExplorer <> nil then begin
    FExplorers := TExplorers.Create(nil);
    FExplorers.ConnectTo(OutlookApp.Explorers);
    FExplorers.OnNewExplorer := DoNewExplorer;
    DoNewExplorer(nil, OutlookApp.ActiveExplorer);
  end;
end;

procedure TAddInModule.adxCOMAddInModuleAddInFinalize(Sender: TObject);
begin
  FExplorersList.Free;
  if Assigned(FExplorers) then FreeAndNil(FExplorers);
end;

procedure TAddInModule.DoNewExplorer(ASender: TObject; const Explorer: _Explorer);
var
  Expl: TExplorer;
begin
  Expl := TExplorer.Create(nil);
  Expl.ConnectTo(Explorer);
  Expl.OnClose := DoExplorerClose;
  FExplorersList.Add(Expl);
end;

procedure TAddInModule.DoExplorerClose(ASender: TObject);
var
  Index: Integer;
begin
  Index := FExplorersList.IndexOf(ASender);
  if Index >= 0 then begin
    TExplorer(FExplorersList[Index]).Free;
    FExplorersList.Delete(Index);
  end;
  SaveParams(ExplorerCmdBar);
end;

initialization
  TadxFactory.Create(ComServer, TADX_OL_TempCmdBar, CLASS_ADX_OL_TempCmdBar, TAddInModule);

end.
